

set -ex



test -f ${PREFIX}/lib/libgflags.so
test -f ${PREFIX}/lib/libgflags_nothreads.so
test -f ${PREFIX}/lib/libgflags.a
test -f ${PREFIX}/lib/libgflags_nothreads.a
conda inspect linkages -p $PREFIX gflags
exit 0
